@@ -1,5 +1,3 @@
-import warnings
-
 import pandas as pd
 from dagster_pandas.constraints import (
     ColumnDTypeFnConstraint,
@@ -9,17 +7,19 @@ from dagster_pandas.constraints import (
 from dagster_pandas.validation import PandasColumn, validate_constraints
 
 from dagster import (
+    AssetMaterialization,
     DagsterInvariantViolationError,
     DagsterType,
     EventMetadataEntry,
     Field,
-    Materialization,
     StringSource,
     TypeCheck,
     check,
+    dagster_type_loader,
+    dagster_type_materializer,
 )
 from dagster.config.field_utils import Selector
-from dagster.core.types.config_schema import input_selector_schema, output_selector_schema
+from dagster.utils.backcompat import canonicalize_backcompat_args
 
 CONSTRAINT_BLACKLIST = {ColumnDTypeFnConstraint, ColumnDTypeInSetConstraint}
 
@@ -28,7 +28,7 @@ def dict_without_keys(ddict, *keys):
     return {key: value for key, value in ddict.items() if key not in set(keys)}
 
 
-@output_selector_schema(
+@dagster_type_materializer(
     Selector(
         {
             'csv': {
@@ -40,10 +40,9 @@ def dict_without_keys(ddict, *keys):
         },
     )
 )
-def dataframe_output_schema(_context, file_type, file_options, pandas_df):
-    check.str_param(file_type, 'file_type')
-    check.dict_param(file_options, 'file_options')
+def dataframe_materializer(_context, config, pandas_df):
     check.inst_param(pandas_df, 'pandas_df', pd.DataFrame)
+    file_type, file_options = list(config.items())[0]
 
     if file_type == 'csv':
         path = file_options['path']
@@ -55,10 +54,10 @@ def dataframe_output_schema(_context, file_type, file_options, pandas_df):
     else:
         check.failed('Unsupported file_type {file_type}'.format(file_type=file_type))
 
-    return Materialization.file(file_options['path'])
+    return AssetMaterialization.file(file_options['path'])
 
 
-@input_selector_schema(
+@dagster_type_loader(
     Selector(
         {
             'csv': {
@@ -70,9 +69,8 @@ def dataframe_output_schema(_context, file_type, file_options, pandas_df):
         },
     )
 )
-def dataframe_input_schema(_context, file_type, file_options):
-    check.str_param(file_type, 'file_type')
-    check.dict_param(file_options, 'file_options')
+def dataframe_loader(_context, config):
+    file_type, file_options = list(config.items())[0]
 
     if file_type == 'csv':
         path = file_options['path']
@@ -105,8 +103,8 @@ DataFrame = DagsterType(
     description='''Two-dimensional size-mutable, potentially heterogeneous
     tabular data structure with labeled axes (rows and columns).
     See http://pandas.pydata.org/''',
-    input_hydration_config=dataframe_input_schema,
-    output_materialization_config=dataframe_output_schema,
+    loader=dataframe_loader,
+    materializer=dataframe_materializer,
     type_check_fn=df_type_check,
 )
 
@@ -156,6 +154,8 @@ def create_dagster_pandas_dataframe_type(
     columns=None,
     event_metadata_fn=None,
     dataframe_constraints=None,
+    loader=None,
+    materializer=None,
     input_hydration_config=None,
     output_materialization_config=None,
 ):
@@ -171,21 +171,17 @@ def create_dagster_pandas_dataframe_type(
             which allow you to express things like summary statistics during runtime.
         dataframe_constraints (Optional[List[DataFrameConstraint]]): A list of objects that inherit from
             :py:class:`~dagster.DataFrameConstraint`. This allows you to express dataframe-level constraints.
-        input_hydration_config (Optional[DagsterTypeLoader]): An instance of a class that
+        loader (Optional[DagsterTypeLoader]): An instance of a class that
             inherits from :py:class:`~dagster.DagsterTypeLoader`. If None, we will default
-            to using the `dataframe_input_schema` input_hydration_config.
-        output_materialization_config (Optional[DagsterTypeMaterializer]): An instance of a class
+            to using `dataframe_loader`.
+        materializer (Optional[DagsterTypeMaterializer]): An instance of a class
             that inherits from :py:class:`~dagster.DagsterTypeMaterializer`. If None, we will
-            default to using the `dataframe_output_schema` output_materialization_config.
+            default to using `dataframe_materializer`.
     """
-    # We allow for the plugging in of input_hydration_config/output_materialization_configs so that
-    # Users can hydrate and persist their custom dataframes via configuration their own way if the default
+    # We allow for the plugging in of dagster_type_loaders/materializers so that
+    # Users can load and matrerialize their custom dataframes via configuration their own way if the default
     # configs don't suffice. This is purely optional.
     check.str_param(name, 'name')
-    warnings.warn(
-        """This method of constructing dataframe types is deprecated,
-     and is planned to be removed in a future version (tentatively 0.10.0)"""
-    )
     event_metadata_fn = check.opt_callable_param(event_metadata_fn, 'event_metadata_fn')
     description = create_dagster_pandas_dataframe_description(
         check.opt_str_param(description, 'description', default=''),
@@ -215,15 +211,22 @@ def create_dagster_pandas_dataframe_type(
             else None,
         )
 
+    loader_ = canonicalize_backcompat_args(
+        loader, 'loader', input_hydration_config, 'input_hydration_config', '0.10.0',
+    )
+    materializer_ = canonicalize_backcompat_args(
+        materializer,
+        'materializer',
+        output_materialization_config,
+        'output_materialization_config',
+        '0.10.0',
+    )
+
     return DagsterType(
         name=name,
         type_check_fn=_dagster_type_check,
-        input_hydration_config=input_hydration_config
-        if input_hydration_config
-        else dataframe_input_schema,
-        output_materialization_config=output_materialization_config
-        if output_materialization_config
-        else dataframe_output_schema,
+        loader=loader_ if loader_ else dataframe_loader,
+        materializer=materializer_ if materializer_ else dataframe_materializer,
         description=description,
     )
 
@@ -234,6 +237,8 @@ def create_structured_dataframe_type(
     columns_validator=None,
     columns_aggregate_validator=None,
     dataframe_validator=None,
+    loader=None,
+    materializer=None,
     input_hydration_config=None,
     output_materialization_config=None,
 ):
@@ -252,12 +257,12 @@ def create_structured_dataframe_type(
         dataframe_validator (Optional[Union[ConstraintWithMetadata, MultiConstraintWithMetadata]]):
                     what dataframe-wide validation you want to have applied.
                     Leave empty for no dataframe-wide validation.
-        input_hydration_config (Optional[DagsterTypeLoader]): An instance of a class that
+        loader (Optional[DagsterTypeLoader]): An instance of a class that
             inherits from :py:class:`~dagster.DagsterTypeLoader`. If None, we will default
-            to using the `dataframe_input_schema` input_hydration_config.
-        output_materialization_config (Optional[DagsterTypeMaterializer]): An instance of a class
+            to using `dataframe_loader`.
+        materializer (Optional[DagsterTypeMaterializer]): An instance of a class
             that inherits from :py:class:`~dagster.DagsterTypeMaterializer`. If None, we will
-            default to using the `dataframe_output_schema` output_materialization_config.
+            default to using `dataframe_materializer`.
 
     Returns:
         a DagsterType with the corresponding name and packaged validation.
@@ -273,20 +278,21 @@ def create_structured_dataframe_type(
                 ),
             )
         individual_result_dict = {}
+
+        if dataframe_validator is not None:
+            individual_result_dict["dataframe"] = dataframe_validator.validate(value)
         if columns_validator is not None:
             individual_result_dict["columns"] = columns_validator.validate(value)
 
         if columns_aggregate_validator is not None:
-            individual_result_dict["column aggregates"] = columns_aggregate_validator.validate(
+            individual_result_dict["column-aggregates"] = columns_aggregate_validator.validate(
                 value
             )
 
-        if dataframe_validator is not None:
-            individual_result_dict["dataframe"] = dataframe_validator.validate(value)
-
         typechecks_succeeded = True
         metadata = []
-        overall_description = ""
+        overall_description = "Failed Constraints: {}"
+        constraint_clauses = []
         for key, result in individual_result_dict.items():
             result_val = result.success
             if result_val:
@@ -296,23 +302,30 @@ def create_structured_dataframe_type(
             metadata.append(
                 EventMetadataEntry.json(result_dict, '{}-constraint-metadata'.format(key),)
             )
-            overall_description += "{} failing constraints, requiring {}".format(
-                key, result.description
-            )
+            constraint_clauses.append("{} failing constraints, {}".format(key, result.description))
+        # returns aggregates, then column, then dataframe
         return TypeCheck(
-            success=typechecks_succeeded, description=overall_description, metadata_entries=metadata
+            success=typechecks_succeeded,
+            description=overall_description.format(constraint_clauses),
+            metadata_entries=sorted(metadata, key=lambda x: x.label),
         )
 
     description = check.opt_str_param(description, 'description', default='')
+    loader_ = canonicalize_backcompat_args(
+        loader, 'loader', input_hydration_config, 'input_hydration_config', '0.10.0',
+    )
+    materializer_ = canonicalize_backcompat_args(
+        materializer,
+        'materializer',
+        output_materialization_config,
+        'output_materialization_config',
+        '0.10.0',
+    )
     return DagsterType(
         name=name,
         type_check_fn=_dagster_type_check,
-        input_hydration_config=input_hydration_config
-        if input_hydration_config
-        else dataframe_input_schema,
-        output_materialization_config=output_materialization_config
-        if output_materialization_config
-        else dataframe_output_schema,
+        loader=loader_ if loader_ else dataframe_loader,
+        materializer=materializer_ if materializer_ else dataframe_materializer,
         description=description,
     )
 
